<p align="center">
  <img height="150" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/logo.svg">
</p>
<br/>

<p align="center">
<img height="16" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/icons/pest.svg" /> » python <img height="16" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/icons/python.svg" /> web application framework designed for constructing scalable APIs, drawing inspiration from <a href="https://docs.nestjs.com/"> nest.js</a> <img height="16" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/icons/nestjs.svg" /> and based on <a href="https://fastapi.tiangolo.com/"> fastapi</a> <img height="16" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/icons/fastapi.svg" />.
</p>

<br/>

<p align="center">
  <img height="74" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/latex.svg">
</p>

<br />
<p align="center">
━━━&nbsp&nbsp&nbsp&nbsp<img height="16" src="https://raw.githubusercontent.com/lucas-labs/pest/master/.github/img/icons/pest.svg" />&nbsp&nbsp&nbsp&nbsp━━━
</p>
<br />
